EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Connectors_CreateOrUpdateConnector',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Connector_Id',
    /* Description_Text        */ 'Creates a new connector in the system, or updates an existing one.'
GO

IF OBJECT_ID('[Connectors_CreateOrUpdateConnector]') IS NOT NULL DROP PROCEDURE [Connectors_CreateOrUpdateConnector]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [Connectors_CreateOrUpdateConnector]
(
	@FeedType_Name VARCHAR(20),
	@Connector_Name NVARCHAR(100),
	@Connector_Url VARCHAR(250),
	@ConnectorConfiguration_Xml XML,
	@Connector_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [Connectors] WITH (UPDLOCK) WHERE [Connector_Id] = @Connector_Id)
	BEGIN

		UPDATE [Connectors]
		   SET [Connector_Name] = @Connector_Name,
			   [Connector_Url] = @Connector_Url,
			   [ConnectorConfiguration_Xml] = @ConnectorConfiguration_Xml
		 WHERE [Connector_Id] = @Connector_Id

		EXEC [Events_RaiseEvent] 'CONMDC', NULL, 'Connector_Id', @Connector_Id

	END
	ELSE
	BEGIN

		INSERT INTO [Connectors]
		(
			[Connector_Name],
			[Connector_Url],
			[FeedType_Name],
			[Status_Code],
			[ConnectorConfiguration_Xml]
		)
		VALUES
		(
			@Connector_Name,
			@Connector_Url,
			@FeedType_Name,
			'U',
			@ConnectorConfiguration_Xml
		)

		SET @Connector_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'CONNWC', NULL, 'Connector_Id', @Connector_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Connectors_CreateOrUpdateConnector] TO [ProGetUser_Role]
GO